@@ -17,8 +17,8 @@ def pandas_max_print() -> None:
 def train_test_split_arr(arr: list, ratio: float, shuffle=False):
     """
     @param arr:待拆分的列表
-    @param ratio：希望得到的拆分后的列表数量的比例
-    @param shuffle: random shuffle the arr
+    @param ratio:希望得到的拆分后的列表数量的比例
+    @param shuffle:是否随机打乱顺序
     @return:两个列表，第一个是长度比例为ratio的列表，第二个列表是raw列表拆出之后剩下的元素
     """
     if shuffle:
